import request from './request'
import { LoginUser, } from './api'



const jsApiList = [
  'updateAppMessageShareData',
  'updateTimelineShareData',
  'onMenuShareTimeline',
  'onMenuShareAppMessage',
  'onMenuShareQQ',
  'onMenuShareWeibo',
  'onMenuShareQZone'
]

function initSDK (url) {
  request(`/api/wx/jssdk?url=${encodeURIComponent(url)}`)
    .then((res) => {
      window.wx.config({
        debug: process.env.NODE_ENV === 'development', // 开启调试模式,调用的所有api的返回值会在客户端alert出来，若要查看传入的参数，可以在pc端打开，参数信息会通过log打出，仅在pc端时才会打印。
        appId: res.appId, // 必填，公众号的唯一标识
        timestamp: res.timestamp, // 必填，生成签名的时间戳
        nonceStr: res.nonceStr, // 必填，生成签名的随机串
        signature: res.signature, // 必填，签名
        jsApiList // 必填，需要使用的JS接口列表
      })
    })
}
// Vue.use(Vuex)

/**
 * 分享
 * @param {*} opt
 */
export function share (opt) {
  const { origin, pathname, search } = window.location
  // const defaultLink = origin + pathname
  const defaultImg = `${origin}${pathname}images/share.png`

  const link = origin + pathname + search // window.location.href
  const imgUrl = opt.imgUrl || defaultImg

  initSDK(link)
  window.wx.ready(function () {
    jsApiList.map((apiName) => {
      const fn = window.wx[apiName]
      if (typeof fn === 'function') {
        fn({
          title: opt.title || '为岸线圆梦，摩天轮圆满大作战！', // 分享标题
          link, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
          imgUrl, // 分享图标
          desc: opt.desc || '快来助力华侨城欢乐滨江摩天轮挂轿厢'
        })
      }
    })
  })
}


export function Login () {
  console.log(1);
  const code = process.env.NODE_ENV === 'development' ? '123' : getCode()

  let isLoaded = false; //定义变量


  //执行Timeout 如果一秒内登陆成功，由LoginUser改变isLoaded状态，Timeout 一秒后发现isLoaded为true，则关闭。
  const t = setTimeout(() => {
    console.log(2);

    if (isLoaded) {
      console.log(isLoaded);

      hideLoading()
    } else {
      console.log('isLoaded=true');

      isLoaded = true
    }
    clearTimeout(t);
  }, 2000);


  return LoginUser(code).then(e => {
    console.log("🚀 ~ file: initial.js ~ line 85 ~ returnLoginUser ~ code", code)
    // PVsum
    console.log(e);
    let userInfo = {
      token: e.token,
      name: e.person.name,
      phone: e.person.phone,
      personId: e.person.personId,
    }

    console.log(3, isLoaded);



    try {
      share({
        title: '为岸线圆梦，摩天轮圆满大作战！',
        desc: '快来助力华侨城欢乐滨江摩天轮挂轿厢'
      })
    } catch (error) {
      console.error(error)
    }
    if (isLoaded) {
      console.log('hideLoading', isLoaded);
      hideLoading()


    } else {
      isLoaded = true

      console.log(4, isLoaded);

    }
    // setTimeout(() => {
    //   console.log("🚀 ~ file: initial.js ~ line 110 ~ setTimeout ~ isLoaded", isLoaded)

    //   if (isLoaded) {
    //     hideLoading()
    //   } else {

    //     isLoaded = true
    //   }
    // }, 5000)


    return;
  })
}

function hideLoading () {
  document.getElementsByClassName('boxZoom')[0].style = "display: none"

}

/**
 * 获取 code
 * @returns 
 */
export function getCode () {
  const matched = /[?&]*code=([^&]+)/.exec(location.search)
  if (matched) {
    return decodeURIComponent(matched[1])
  }
}

/**
 * 跳转授权页面
 */
export function redirect (force) {
  if (process.env.NODE_ENV === 'development') return;

  const originCode = localStorage.getItem('wxcode');
  const wxfirst = localStorage.getItem('wxfirst') === null;
  const queryCode = getCode();
  const scope = 'snsapi_userinfo'

  localStorage.setItem('wxcode', queryCode)
  localStorage.setItem('wxfirst', 'not');


  if (force || wxfirst || !queryCode || queryCode === originCode) {

    const local = encodeURIComponent(location.origin + location.pathname)
    const url = `https://open.weixin.qq.com/connect/oauth2/authorize?appid=wxd3bab568bc42d1de&redirect_uri=${local}&response_type=code&scope=${scope}&state=123#wechat_redirect`
    window.location.href = url;
  }
}


/**
 * 获取 openid
 * @returns 
 */
export function getOpenId () {
  if (process.env.NODE_ENV === 'development') return Promise.resolve('123');

  const code = getCode()
  if (!code) {
    return Promise.reject("获取用户信息失败, 请刷新重试")
  }

  return request(`https://api.h5.njyunzhi.com/mp/openid?code=${encodeURIComponent(code)}`)
}

/**
 * 获取 openid
 * @returns 
 */
export function getUserInfo () {
  if (process.env.NODE_ENV === 'development') return Promise.resolve({ openid: '123' });

  const code = getCode()
  if (!code) {
    return Promise.reject("获取用户信息失败, 请刷新重试")
  }

  return request(`https://api.h5.njyunzhi.com/mp/userinfo?code=${encodeURIComponent(code)}`)
}
